/** @jsx jsx */
import { forwardRef } from 'react';
import { css, jsx } from '@emotion/react';
import { SPACING_SCALE } from '../constants';
const flexAlignItemsMap = {
  center: css({
    alignItems: 'center'
  }),
  baseline: css({
    alignItems: 'baseline'
  }),
  flexStart: css({
    alignItems: 'flex-start'
  }),
  flexEnd: css({
    alignItems: 'flex-end'
  })
};
const flexJustifyContentMap = {
  center: css({
    justifyContent: 'center'
  }),
  flexStart: css({
    justifyContent: 'flex-start'
  }),
  flexEnd: css({
    justifyContent: 'flex-end'
  })
};
const baseStyles = css({
  display: 'flex',
  boxSizing: 'border-box',
  flexDirection: 'column'
});
/**
 * __Stack__
 *
 * Stack is a primitive component based on flexbox that manages the vertical layout of direct children.
 * Renders a `div` by default.
 *
 */

const Stack = /*#__PURE__*/forwardRef(({
  gap,
  alignItems,
  justifyContent,
  children,
  testId
}, ref) => {
  return jsx("div", {
    css: [baseStyles, gap && gapMap[gap], alignItems && flexAlignItemsMap[alignItems], justifyContent && flexJustifyContentMap[justifyContent]],
    "data-testid": testId,
    ref: ref
  }, children);
});
Stack.displayName = 'Stack';
export default Stack;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::36d00b5586593733c7f84e9a10ddb7fd>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["gap"]
 */

const gapMap = {
  'sp-0': css({
    gap: SPACING_SCALE['sp-0']
  }),
  'sp-25': css({
    gap: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    gap: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    gap: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    gap: SPACING_SCALE['sp-100']
  }),
  'sp-150': css({
    gap: SPACING_SCALE['sp-150']
  }),
  'sp-200': css({
    gap: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    gap: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    gap: SPACING_SCALE['sp-400']
  }),
  'sp-500': css({
    gap: SPACING_SCALE['sp-500']
  }),
  'sp-600': css({
    gap: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    gap: SPACING_SCALE['sp-800']
  })
};
/**
 * @codegenEnd
 */